@@ -26,15 +26,18 @@ class NearestModifier(Modifier):
     def execute(
         self, r: ReadRequestBuildingBlocks, h: DataStoreHelper
     ) -> ReadRequestBuildingBlocks:
-        if not r.modifier_context or "frequency" not in r.modifier_context:
-            raise RuntimeError(
-                "Nearest modifier requires a frequency modifier."
-            )
 
-        frequency_tbl: Table = r.modifier_context["frequency"]["table"]
+        if r.modifier_context and 'frequency' in r.modifier_context:
+            frequency_tbl =  r.modifier_context["frequency"]["table"]
+            column_name = FrequencyModifier.FREQUENCY_COLUMN_NAME
+        elif r.effective_dating_table is not None:
+            frequency_tbl = r.effective_dating_table
+            column_name = 'dt'
+        else:
+            raise ValueError('Bulding blocks do not contain a frequency table.')
 
         p = [r.asset_table.c.get(x) for x in self.partition_fields] + [
-            frequency_tbl.c.get(FrequencyModifier.FREQUENCY_COLUMN_NAME)
+            frequency_tbl.c.get(column_name)
         ]
         o = [
             r.asset_table.c.get(x[0]).desc()
@@ -74,6 +77,10 @@ class FrequencyModifier(Modifier):
     def execute(
         self, r: ReadRequestBuildingBlocks, h: DataStoreHelper
     ) -> ReadRequestBuildingBlocks:
+
+        if r.effective_dating_table is not None:
+            raise ValueError('A frequency modifier cannot be applied to non range queries.')
+
         ranges = pd.bdate_range(
             start=r.effective_start_dt,
             end=r.effective_end_dt,
